# remirepo spec file for php-pecl-opentelemetry
#
# Copyright (c) 2023-2024 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:%scl_package php-pecl-opentelemetry}

%bcond_without     tests

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  opentelemetry
%global ini_name   40-%{pecl_name}.ini

%global upstream_version 1.0.3
#global upstream_prever  beta1
%global upstream_lower   %(echo %{upstream_prever} | tr '[:upper:]' '[:lower:]')
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Summary:        OpenTelemetry auto-instrumentation support extension
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_lower}}
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        Apache-2.0
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?dtsprefix}gcc-c++
BuildRequires:  %{?scl_prefix}php-devel >= 8.0
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
OpenTelemetry auto-instrumentation extension.

This is a PHP extension for OpenTelemetry, to enable auto-instrumentation.
It is based on zend_observer and requires php8+

The extension allows creating pre and post hook functions to arbitrary PHP
functions and methods, which allows those methods to be wrapped with telemetry.


Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd %{sources}
%if 0%{?rhel} == 7
sed -e 's/-Werror//' -i config.m4
%endif

: Sanity check, really often broken
extver=$(sed -n '/#define PHP_OPENTELEMETRY_VERSION /{s/.* "//;s/".*$//;p}' php_%{pecl_name}.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{summary}
extension=%{pecl_name}.so

; Configuration
;opentelemetry.conflicts = 'blackfire'
;opentelemetry.validate_hook_functions = On
;opentelemetry.allow_stack_extension = Off
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --enable-opentelemetry \
    --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --enable-opentelemetry \
    --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep -i '^%{pecl_name}$'
%endif



%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
#%%doc %%{pecl_docdir}/%%{pecl_name}
%{?_licensedir:%license %{sources}/LICENSE*}

%{pecl_xmldir}/%{name}.xml
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Sat May  4 2024 Remi Collet <remi@remirepo.net> - 1.0.3-1
- update to 1.0.3

* Thu May  2 2024 Remi Collet <remi@remirepo.net> - 1.0.3~beta1-1
- update to 1.0.3beta1

* Thu Apr 11 2024 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Tue Mar 26 2024 Remi Collet <remi@remirepo.net> - 1.0.2~beta3-1
- update to 1.0.2beta3

* Tue Mar 19 2024 Remi Collet <remi@remirepo.net> - 1.0.2~beta2-1
- update to 1.0.2beta2

* Tue Feb  6 2024 Remi Collet <remi@remirepo.net> - 1.0.2~beta1-1
- update to 1.0.2beta1

* Mon Feb  5 2024 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Tue Jan 30 2024 Remi Collet <remi@remirepo.net> - 1.0.1~beta2-1
- update to 1.0.1beta2

* Thu Jan 25 2024 Remi Collet <remi@remirepo.net> - 1.0.1~beta1-1
- update to 1.0.1beta1

* Wed Oct 25 2023 Remi Collet <remi@remirepo.net> - 1.0.0-1
- update to 1.0.0

* Fri Oct 20 2023 Remi Collet <remi@remirepo.net> - 1.0.0~RC3-1
- update to 1.0.0RC3

* Tue Oct 17 2023 Remi Collet <remi@remirepo.net> - 1.0.0~RC2-1
- update to 1.0.0RC2

* Tue Sep 12 2023 Remi Collet <remi@remirepo.net> - 1.0.0~RC1-1
- update to 1.0.0RC1

* Tue Sep  5 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta7-1
- update to 1.0.0beta7

* Wed Jun 14 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta6-1
- update to 1.0.0beta6

* Wed May 10 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta5-1
- update to 1.0.0beta5

* Wed Apr 19 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta4-1
- update to 1.0.0beta4

* Sat Apr  1 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta3-1
- update to 1.0.0beta3
- extension renamed from otel_instrumentation to opentelemetry

* Thu Mar 30 2023 Remi Collet <remi@remirepo.net> - 1.0.0~beta2-1
- initial package, version 1.0.0beta2
- open https://github.com/open-telemetry/opentelemetry-php-instrumentation/issues/45
  missing license file and tests
- open https://github.com/open-telemetry/opentelemetry-php-instrumentation/issues/46
  missing extension version
